@@ -1,7 +1,7 @@
 from os import system
 from hcfg.exceptions import *
 import json
-
+import ast
 
 class hcfgdb():
     def __init__(self,fileName):
@@ -53,7 +53,9 @@ class hcfg():
                     return
                 name = object[0].strip(" ")
                 value = hcfg.assignValue(object[1])
-                if(value.startswith("{") and value.endswith("}")):
+                if(value.startswith("{")):
+                    value = value.replace("'",'"')
+                    print(value)
                     dict = json.loads(value)
                     buffer[name] = dict
                 else:
